import 'package:test/test.dart';
import 'package:date_time_format/date_time_format.dart';

void main() {
  test('Validate Formats', () {
    _dateTimeFormats.forEach((format, expectedValues) {
      for (var i = 0; i < _dateTimes.length; i++) {
        final result = DateTimeFormat.format(_dateTimes[i], format: format);
        expect(expectedValues[i], equals(result));
      }
    });
  });
}

final _dateTimes = <DateTime>[
  DateTime.utc(2015, 1, 1, 1, 1, 1, 1, 1),
  DateTime.utc(2016, 2, 29, 3, 12),
  DateTime.utc(2017, 3, 19, 17, 23, 30, 60, 323),
  DateTime.utc(2018, 4, 13, 12, 15, 48),
  DateTime.utc(2019, 5, 8, 9, 35, 16, 2, 200),
  DateTime.utc(2020, 6, 25, 22),
  DateTime.utc(2021, 7, 14, 15, 6, 55, 234),
  DateTime.utc(2022, 8, 16),
  DateTime.utc(2023, 9, 2, 23, 59, 59, 999, 999),
  DateTime.utc(2024, 10, 15, 19, 42, 5),
  DateTime.utc(2025, 11, 30, 12),
  DateTime.utc(2026, 12, 7),
];

const _dateTimeFormats = <String, List<String>>{
  DateTimeFormats.american: <String>[
    'January 1, 2015 1:01 am',
    'February 29, 2016 3:12 am',
    'March 19, 2017 5:23 pm',
    'April 13, 2018 12:15 pm',
    'May 8, 2019 9:35 am',
    'June 25, 2020 10:00 pm',
    'July 14, 2021 3:06 pm',
    'August 16, 2022 12:00 am',
    'September 2, 2023 11:59 pm',
    'October 15, 2024 7:42 pm',
    'November 30, 2025 12:00 pm',
    'December 7, 2026 12:00 am',
  ],
  DateTimeFormats.american24Hour: <String>[
    'January 1, 2015 01:01',
    'February 29, 2016 03:12',
    'March 19, 2017 17:23',
    'April 13, 2018 12:15',
    'May 8, 2019 09:35',
    'June 25, 2020 22:00',
    'July 14, 2021 15:06',
    'August 16, 2022 00:00',
    'September 2, 2023 23:59',
    'October 15, 2024 19:42',
    'November 30, 2025 12:00',
    'December 7, 2026 00:00',
  ],
  DateTimeFormats.americanAbbr: <String>[
    'Jan 1, 2015 1:01 am',
    'Feb 29, 2016 3:12 am',
    'Mar 19, 2017 5:23 pm',
    'Apr 13, 2018 12:15 pm',
    'May 8, 2019 9:35 am',
    'Jun 25, 2020 10:00 pm',
    'Jul 14, 2021 3:06 pm',
    'Aug 16, 2022 12:00 am',
    'Sep 2, 2023 11:59 pm',
    'Oct 15, 2024 7:42 pm',
    'Nov 30, 2025 12:00 pm',
    'Dec 7, 2026 12:00 am',
  ],
  DateTimeFormats.americanAbbr24Hour: <String>[
    'Jan 1, 2015 01:01',
    'Feb 29, 2016 03:12',
    'Mar 19, 2017 17:23',
    'Apr 13, 2018 12:15',
    'May 8, 2019 09:35',
    'Jun 25, 2020 22:00',
    'Jul 14, 2021 15:06',
    'Aug 16, 2022 00:00',
    'Sep 2, 2023 23:59',
    'Oct 15, 2024 19:42',
    'Nov 30, 2025 12:00',
    'Dec 7, 2026 00:00',
  ],
  DateTimeFormats.americanAbbrExtended: <String>[
    'Jan 1, 2015 1:01 am GMT',
    'Feb 29, 2016 3:12 am GMT',
    'Mar 19, 2017 5:23 pm GMT',
    'Apr 13, 2018 12:15 pm GMT',
    'May 8, 2019 9:35 am GMT',
    'Jun 25, 2020 10:00 pm GMT',
    'Jul 14, 2021 3:06 pm GMT',
    'Aug 16, 2022 12:00 am GMT',
    'Sep 2, 2023 11:59 pm GMT',
    'Oct 15, 2024 7:42 pm GMT',
    'Nov 30, 2025 12:00 pm GMT',
    'Dec 7, 2026 12:00 am GMT',
  ],
  DateTimeFormats.americanAbbrExtended24Hour: <String>[
    'Jan 1, 2015 01:01 GMT',
    'Feb 29, 2016 03:12 GMT',
    'Mar 19, 2017 17:23 GMT',
    'Apr 13, 2018 12:15 GMT',
    'May 8, 2019 09:35 GMT',
    'Jun 25, 2020 22:00 GMT',
    'Jul 14, 2021 15:06 GMT',
    'Aug 16, 2022 00:00 GMT',
    'Sep 2, 2023 23:59 GMT',
    'Oct 15, 2024 19:42 GMT',
    'Nov 30, 2025 12:00 GMT',
    'Dec 7, 2026 00:00 GMT',
  ],
  DateTimeFormats.americanDayOfWeekAbbr: <String>[
    'Thu, January 1, 2015 1:01 am',
    'Mon, February 29, 2016 3:12 am',
    'Sun, March 19, 2017 5:23 pm',
    'Fri, April 13, 2018 12:15 pm',
    'Wed, May 8, 2019 9:35 am',
    'Thu, June 25, 2020 10:00 pm',
    'Wed, July 14, 2021 3:06 pm',
    'Tue, August 16, 2022 12:00 am',
    'Sat, September 2, 2023 11:59 pm',
    'Tue, October 15, 2024 7:42 pm',
    'Sun, November 30, 2025 12:00 pm',
    'Mon, December 7, 2026 12:00 am',
  ],
  DateTimeFormats.americanDayOfWeekAbbr24Hour: <String>[
    'Thu, January 1, 2015 01:01',
    'Mon, February 29, 2016 03:12',
    'Sun, March 19, 2017 17:23',
    'Fri, April 13, 2018 12:15',
    'Wed, May 8, 2019 09:35',
    'Thu, June 25, 2020 22:00',
    'Wed, July 14, 2021 15:06',
    'Tue, August 16, 2022 00:00',
    'Sat, September 2, 2023 23:59',
    'Tue, October 15, 2024 19:42',
    'Sun, November 30, 2025 12:00',
    'Mon, December 7, 2026 00:00',
  ],
  DateTimeFormats.americanExtended: <String>[
    'January 1, 2015 1:01 am GMT',
    'February 29, 2016 3:12 am GMT',
    'March 19, 2017 5:23 pm GMT',
    'April 13, 2018 12:15 pm GMT',
    'May 8, 2019 9:35 am GMT',
    'June 25, 2020 10:00 pm GMT',
    'July 14, 2021 3:06 pm GMT',
    'August 16, 2022 12:00 am GMT',
    'September 2, 2023 11:59 pm GMT',
    'October 15, 2024 7:42 pm GMT',
    'November 30, 2025 12:00 pm GMT',
    'December 7, 2026 12:00 am GMT',
  ],
  DateTimeFormats.americanExtended24Hour: <String>[
    'January 1, 2015 01:01 GMT',
    'February 29, 2016 03:12 GMT',
    'March 19, 2017 17:23 GMT',
    'April 13, 2018 12:15 GMT',
    'May 8, 2019 09:35 GMT',
    'June 25, 2020 22:00 GMT',
    'July 14, 2021 15:06 GMT',
    'August 16, 2022 00:00 GMT',
    'September 2, 2023 23:59 GMT',
    'October 15, 2024 19:42 GMT',
    'November 30, 2025 12:00 GMT',
    'December 7, 2026 00:00 GMT',
  ],
  DateTimeFormats.commonLogFormat: <String>[
    '01/Jan/2015:01:01:01 +0000',
    '29/Feb/2016:03:12:00 +0000',
    '19/Mar/2017:17:23:30 +0000',
    '13/Apr/2018:12:15:48 +0000',
    '08/May/2019:09:35:16 +0000',
    '25/Jun/2020:22:00:00 +0000',
    '14/Jul/2021:15:06:55 +0000',
    '16/Aug/2022:00:00:00 +0000',
    '02/Sep/2023:23:59:59 +0000',
    '15/Oct/2024:19:42:05 +0000',
    '30/Nov/2025:12:00:00 +0000',
    '07/Dec/2026:00:00:00 +0000',
  ],
  DateTimeFormats.cookie: <String>[
    'Thu, 01-01-2015 01:01:01 GMT',
    'Mon, 29-02-2016 03:12:00 GMT',
    'Sun, 19-03-2017 17:23:30 GMT',
    'Fri, 13-04-2018 12:15:48 GMT',
    'Wed, 08-05-2019 09:35:16 GMT',
    'Thu, 25-06-2020 22:00:00 GMT',
    'Wed, 14-07-2021 15:06:55 GMT',
    'Tue, 16-08-2022 00:00:00 GMT',
    'Sat, 02-09-2023 23:59:59 GMT',
    'Tue, 15-10-2024 19:42:05 GMT',
    'Sun, 30-11-2025 12:00:00 GMT',
    'Mon, 07-12-2026 00:00:00 GMT',
  ],
  DateTimeFormats.dayOfWeek: <String>[
    'Thursday, January 1, 2015',
    'Monday, February 29, 2016',
    'Sunday, March 19, 2017',
    'Friday, April 13, 2018',
    'Wednesday, May 8, 2019',
    'Thursday, June 25, 2020',
    'Wednesday, July 14, 2021',
    'Tuesday, August 16, 2022',
    'Saturday, September 2, 2023',
    'Tuesday, October 15, 2024',
    'Sunday, November 30, 2025',
    'Monday, December 7, 2026',
  ],
  DateTimeFormats.dayOfWeek12Hour: <String>[
    'Thursday, January 1, 2015 1:01 am',
    'Monday, February 29, 2016 3:12 am',
    'Sunday, March 19, 2017 5:23 pm',
    'Friday, April 13, 2018 12:15 pm',
    'Wednesday, May 8, 2019 9:35 am',
    'Thursday, June 25, 2020 10:00 pm',
    'Wednesday, July 14, 2021 3:06 pm',
    'Tuesday, August 16, 2022 12:00 am',
    'Saturday, September 2, 2023 11:59 pm',
    'Tuesday, October 15, 2024 7:42 pm',
    'Sunday, November 30, 2025 12:00 pm',
    'Monday, December 7, 2026 12:00 am',
  ],
  DateTimeFormats.dayOfWeek12HourExtended: <String>[
    'Thursday, January 1, 2015 1:01 am GMT',
    'Monday, February 29, 2016 3:12 am GMT',
    'Sunday, March 19, 2017 5:23 pm GMT',
    'Friday, April 13, 2018 12:15 pm GMT',
    'Wednesday, May 8, 2019 9:35 am GMT',
    'Thursday, June 25, 2020 10:00 pm GMT',
    'Wednesday, July 14, 2021 3:06 pm GMT',
    'Tuesday, August 16, 2022 12:00 am GMT',
    'Saturday, September 2, 2023 11:59 pm GMT',
    'Tuesday, October 15, 2024 7:42 pm GMT',
    'Sunday, November 30, 2025 12:00 pm GMT',
    'Monday, December 7, 2026 12:00 am GMT',
  ],
  DateTimeFormats.dayOfWeek24Hour: <String>[
    'Thursday, January 1, 2015 01:01',
    'Monday, February 29, 2016 03:12',
    'Sunday, March 19, 2017 17:23',
    'Friday, April 13, 2018 12:15',
    'Wednesday, May 8, 2019 09:35',
    'Thursday, June 25, 2020 22:00',
    'Wednesday, July 14, 2021 15:06',
    'Tuesday, August 16, 2022 00:00',
    'Saturday, September 2, 2023 23:59',
    'Tuesday, October 15, 2024 19:42',
    'Sunday, November 30, 2025 12:00',
    'Monday, December 7, 2026 00:00',
  ],
  DateTimeFormats.dayOfWeek24HourExtended: <String>[
    'Thursday, January 1, 2015 01:01 GMT',
    'Monday, February 29, 2016 03:12 GMT',
    'Sunday, March 19, 2017 17:23 GMT',
    'Friday, April 13, 2018 12:15 GMT',
    'Wednesday, May 8, 2019 09:35 GMT',
    'Thursday, June 25, 2020 22:00 GMT',
    'Wednesday, July 14, 2021 15:06 GMT',
    'Tuesday, August 16, 2022 00:00 GMT',
    'Saturday, September 2, 2023 23:59 GMT',
    'Tuesday, October 15, 2024 19:42 GMT',
    'Sunday, November 30, 2025 12:00 GMT',
    'Monday, December 7, 2026 00:00 GMT',
  ],
  DateTimeFormats.dayOfWeekAbbr: <String>[
    'Thu, Jan 1, 2015',
    'Mon, Feb 29, 2016',
    'Sun, Mar 19, 2017',
    'Fri, Apr 13, 2018',
    'Wed, May 8, 2019',
    'Thu, Jun 25, 2020',
    'Wed, Jul 14, 2021',
    'Tue, Aug 16, 2022',
    'Sat, Sep 2, 2023',
    'Tue, Oct 15, 2024',
    'Sun, Nov 30, 2025',
    'Mon, Dec 7, 2026',
  ],
  DateTimeFormats.dayOfWeekAbbr12Hour: <String>[
    'Thu, Jan 1, 2015 1:01 am',
    'Mon, Feb 29, 2016 3:12 am',
    'Sun, Mar 19, 2017 5:23 pm',
    'Fri, Apr 13, 2018 12:15 pm',
    'Wed, May 8, 2019 9:35 am',
    'Thu, Jun 25, 2020 10:00 pm',
    'Wed, Jul 14, 2021 3:06 pm',
    'Tue, Aug 16, 2022 12:00 am',
    'Sat, Sep 2, 2023 11:59 pm',
    'Tue, Oct 15, 2024 7:42 pm',
    'Sun, Nov 30, 2025 12:00 pm',
    'Mon, Dec 7, 2026 12:00 am',
  ],
  DateTimeFormats.dayOfWeekAbbr12HourExtended: <String>[
    'Thu, Jan 1, 2015 1:01 am GMT',
    'Mon, Feb 29, 2016 3:12 am GMT',
    'Sun, Mar 19, 2017 5:23 pm GMT',
    'Fri, Apr 13, 2018 12:15 pm GMT',
    'Wed, May 8, 2019 9:35 am GMT',
    'Thu, Jun 25, 2020 10:00 pm GMT',
    'Wed, Jul 14, 2021 3:06 pm GMT',
    'Tue, Aug 16, 2022 12:00 am GMT',
    'Sat, Sep 2, 2023 11:59 pm GMT',
    'Tue, Oct 15, 2024 7:42 pm GMT',
    'Sun, Nov 30, 2025 12:00 pm GMT',
    'Mon, Dec 7, 2026 12:00 am GMT',
  ],
  DateTimeFormats.dayOfWeekAbbr24Hour: <String>[
    'Thu, Jan 1, 2015 01:01',
    'Mon, Feb 29, 2016 03:12',
    'Sun, Mar 19, 2017 17:23',
    'Fri, Apr 13, 2018 12:15',
    'Wed, May 8, 2019 09:35',
    'Thu, Jun 25, 2020 22:00',
    'Wed, Jul 14, 2021 15:06',
    'Tue, Aug 16, 2022 00:00',
    'Sat, Sep 2, 2023 23:59',
    'Tue, Oct 15, 2024 19:42',
    'Sun, Nov 30, 2025 12:00',
    'Mon, Dec 7, 2026 00:00',
  ],
  DateTimeFormats.dayOfWeekAbbr24HourExtended: <String>[
    'Thu, Jan 1, 2015 01:01 GMT',
    'Mon, Feb 29, 2016 03:12 GMT',
    'Sun, Mar 19, 2017 17:23 GMT',
    'Fri, Apr 13, 2018 12:15 GMT',
    'Wed, May 8, 2019 09:35 GMT',
    'Thu, Jun 25, 2020 22:00 GMT',
    'Wed, Jul 14, 2021 15:06 GMT',
    'Tue, Aug 16, 2022 00:00 GMT',
    'Sat, Sep 2, 2023 23:59 GMT',
    'Tue, Oct 15, 2024 19:42 GMT',
    'Sun, Nov 30, 2025 12:00 GMT',
    'Mon, Dec 7, 2026 00:00 GMT',
  ],
  DateTimeFormats.dayOfWeekAbbrShort: <String>[
    'Thu, Jan 1',
    'Mon, Feb 29',
    'Sun, Mar 19',
    'Fri, Apr 13',
    'Wed, May 8',
    'Thu, Jun 25',
    'Wed, Jul 14',
    'Tue, Aug 16',
    'Sat, Sep 2',
    'Tue, Oct 15',
    'Sun, Nov 30',
    'Mon, Dec 7',
  ],
  DateTimeFormats.dayOfWeekAbbrShort12Hour: <String>[
    'Thu, Jan 1 1:01 am',
    'Mon, Feb 29 3:12 am',
    'Sun, Mar 19 5:23 pm',
    'Fri, Apr 13 12:15 pm',
    'Wed, May 8 9:35 am',
    'Thu, Jun 25 10:00 pm',
    'Wed, Jul 14 3:06 pm',
    'Tue, Aug 16 12:00 am',
    'Sat, Sep 2 11:59 pm',
    'Tue, Oct 15 7:42 pm',
    'Sun, Nov 30 12:00 pm',
    'Mon, Dec 7 12:00 am',
  ],
  DateTimeFormats.dayOfWeekAbbrShort24Hour: <String>[
    'Thu, Jan 1 01:01',
    'Mon, Feb 29 03:12',
    'Sun, Mar 19 17:23',
    'Fri, Apr 13 12:15',
    'Wed, May 8 09:35',
    'Thu, Jun 25 22:00',
    'Wed, Jul 14 15:06',
    'Tue, Aug 16 00:00',
    'Sat, Sep 2 23:59',
    'Tue, Oct 15 19:42',
    'Sun, Nov 30 12:00',
    'Mon, Dec 7 00:00',
  ],
  DateTimeFormats.dayOfWeekShort: <String>[
    'Thursday, January 1',
    'Monday, February 29',
    'Sunday, March 19',
    'Friday, April 13',
    'Wednesday, May 8',
    'Thursday, June 25',
    'Wednesday, July 14',
    'Tuesday, August 16',
    'Saturday, September 2',
    'Tuesday, October 15',
    'Sunday, November 30',
    'Monday, December 7',
  ],
  DateTimeFormats.european: <String>[
    '1 January 2015',
    '29 February 2016',
    '19 March 2017',
    '13 April 2018',
    '8 May 2019',
    '25 June 2020',
    '14 July 2021',
    '16 August 2022',
    '2 September 2023',
    '15 October 2024',
    '30 November 2025',
    '7 December 2026',
  ],
  DateTimeFormats.european12Hour: <String>[
    '1 January 2015 1:01 am',
    '29 February 2016 3:12 am',
    '19 March 2017 5:23 pm',
    '13 April 2018 12:15 pm',
    '8 May 2019 9:35 am',
    '25 June 2020 10:00 pm',
    '14 July 2021 3:06 pm',
    '16 August 2022 12:00 am',
    '2 September 2023 11:59 pm',
    '15 October 2024 7:42 pm',
    '30 November 2025 12:00 pm',
    '7 December 2026 12:00 am',
  ],
  DateTimeFormats.european12HourExtended: <String>[
    '1 January 2015 1:01 am GMT',
    '29 February 2016 3:12 am GMT',
    '19 March 2017 5:23 pm GMT',
    '13 April 2018 12:15 pm GMT',
    '8 May 2019 9:35 am GMT',
    '25 June 2020 10:00 pm GMT',
    '14 July 2021 3:06 pm GMT',
    '16 August 2022 12:00 am GMT',
    '2 September 2023 11:59 pm GMT',
    '15 October 2024 7:42 pm GMT',
    '30 November 2025 12:00 pm GMT',
    '7 December 2026 12:00 am GMT',
  ],
  DateTimeFormats.european24Hour: <String>[
    '1 January 2015 01:01',
    '29 February 2016 03:12',
    '19 March 2017 17:23',
    '13 April 2018 12:15',
    '8 May 2019 09:35',
    '25 June 2020 22:00',
    '14 July 2021 15:06',
    '16 August 2022 00:00',
    '2 September 2023 23:59',
    '15 October 2024 19:42',
    '30 November 2025 12:00',
    '7 December 2026 00:00',
  ],
  DateTimeFormats.european24HourExtended: <String>[
    '1 January 2015 01:01 GMT',
    '29 February 2016 03:12 GMT',
    '19 March 2017 17:23 GMT',
    '13 April 2018 12:15 GMT',
    '8 May 2019 09:35 GMT',
    '25 June 2020 22:00 GMT',
    '14 July 2021 15:06 GMT',
    '16 August 2022 00:00 GMT',
    '2 September 2023 23:59 GMT',
    '15 October 2024 19:42 GMT',
    '30 November 2025 12:00 GMT',
    '7 December 2026 00:00 GMT',
  ],
  DateTimeFormats.europeanAbbr: <String>[
    '1 Jan 2015',
    '29 Feb 2016',
    '19 Mar 2017',
    '13 Apr 2018',
    '8 May 2019',
    '25 Jun 2020',
    '14 Jul 2021',
    '16 Aug 2022',
    '2 Sep 2023',
    '15 Oct 2024',
    '30 Nov 2025',
    '7 Dec 2026',
  ],
  DateTimeFormats.europeanAbbr12Hour: <String>[
    '1 Jan 2015 1:01 am',
    '29 Feb 2016 3:12 am',
    '19 Mar 2017 5:23 pm',
    '13 Apr 2018 12:15 pm',
    '8 May 2019 9:35 am',
    '25 Jun 2020 10:00 pm',
    '14 Jul 2021 3:06 pm',
    '16 Aug 2022 12:00 am',
    '2 Sep 2023 11:59 pm',
    '15 Oct 2024 7:42 pm',
    '30 Nov 2025 12:00 pm',
    '7 Dec 2026 12:00 am',
  ],
  DateTimeFormats.europeanAbbr12HourExtended: <String>[
    '1 Jan 2015 1:01 am GMT',
    '29 Feb 2016 3:12 am GMT',
    '19 Mar 2017 5:23 pm GMT',
    '13 Apr 2018 12:15 pm GMT',
    '8 May 2019 9:35 am GMT',
    '25 Jun 2020 10:00 pm GMT',
    '14 Jul 2021 3:06 pm GMT',
    '16 Aug 2022 12:00 am GMT',
    '2 Sep 2023 11:59 pm GMT',
    '15 Oct 2024 7:42 pm GMT',
    '30 Nov 2025 12:00 pm GMT',
    '7 Dec 2026 12:00 am GMT',
  ],
  DateTimeFormats.europeanAbbr24Hour: <String>[
    '1 Jan 2015 01:01',
    '29 Feb 2016 03:12',
    '19 Mar 2017 17:23',
    '13 Apr 2018 12:15',
    '8 May 2019 09:35',
    '25 Jun 2020 22:00',
    '14 Jul 2021 15:06',
    '16 Aug 2022 00:00',
    '2 Sep 2023 23:59',
    '15 Oct 2024 19:42',
    '30 Nov 2025 12:00',
    '7 Dec 2026 00:00',
  ],
  DateTimeFormats.europeanAbbr24HourExtended: <String>[
    '1 Jan 2015 01:01 GMT',
    '29 Feb 2016 03:12 GMT',
    '19 Mar 2017 17:23 GMT',
    '13 Apr 2018 12:15 GMT',
    '8 May 2019 09:35 GMT',
    '25 Jun 2020 22:00 GMT',
    '14 Jul 2021 15:06 GMT',
    '16 Aug 2022 00:00 GMT',
    '2 Sep 2023 23:59 GMT',
    '15 Oct 2024 19:42 GMT',
    '30 Nov 2025 12:00 GMT',
    '7 Dec 2026 00:00 GMT',
  ],
  DateTimeFormats.exif: <String>[
    '2015:01:01 01:01:01',
    '2016:02:29 03:12:00',
    '2017:03:19 17:23:30',
    '2018:04:13 12:15:48',
    '2019:05:08 09:35:16',
    '2020:06:25 22:00:00',
    '2021:07:14 15:06:55',
    '2022:08:16 00:00:00',
    '2023:09:02 23:59:59',
    '2024:10:15 19:42:05',
    '2025:11:30 12:00:00',
    '2026:12:07 00:00:00',
  ],
  DateTimeFormats.iso8601: <String>[
    '2015-01-01T01:01:01+00:00',
    '2016-02-29T03:12:00+00:00',
    '2017-03-19T17:23:30+00:00',
    '2018-04-13T12:15:48+00:00',
    '2019-05-08T09:35:16+00:00',
    '2020-06-25T22:00:00+00:00',
    '2021-07-14T15:06:55+00:00',
    '2022-08-16T00:00:00+00:00',
    '2023-09-02T23:59:59+00:00',
    '2024-10-15T19:42:05+00:00',
    '2025-11-30T12:00:00+00:00',
    '2026-12-07T00:00:00+00:00',
  ],
  DateTimeFormats.mySql: <String>[
    '2015-01-01 01:01:01',
    '2016-02-29 03:12:00',
    '2017-03-19 17:23:30',
    '2018-04-13 12:15:48',
    '2019-05-08 09:35:16',
    '2020-06-25 22:00:00',
    '2021-07-14 15:06:55',
    '2022-08-16 00:00:00',
    '2023-09-02 23:59:59',
    '2024-10-15 19:42:05',
    '2025-11-30 12:00:00',
    '2026-12-07 00:00:00',
  ],
  DateTimeFormats.rss: <String>[
    'Thu, 01 Jan 2015 01:01:01 +0000',
    'Mon, 29 Feb 2016 03:12:00 +0000',
    'Sun, 19 Mar 2017 17:23:30 +0000',
    'Fri, 13 Apr 2018 12:15:48 +0000',
    'Wed, 08 May 2019 09:35:16 +0000',
    'Thu, 25 Jun 2020 22:00:00 +0000',
    'Wed, 14 Jul 2021 15:06:55 +0000',
    'Tue, 16 Aug 2022 00:00:00 +0000',
    'Sat, 02 Sep 2023 23:59:59 +0000',
    'Tue, 15 Oct 2024 19:42:05 +0000',
    'Sun, 30 Nov 2025 12:00:00 +0000',
    'Mon, 07 Dec 2026 00:00:00 +0000',
  ],
  DateTimeFormats.soap: <String>[
    '2015-01-01T01:01:01.001',
    '2016-02-29T03:12:00.000',
    '2017-03-19T17:23:30.060',
    '2018-04-13T12:15:48.000',
    '2019-05-08T09:35:16.002',
    '2020-06-25T22:00:00.000',
    '2021-07-14T15:06:55.234',
    '2022-08-16T00:00:00.000',
    '2023-09-02T23:59:59.999',
    '2024-10-15T19:42:05.000',
    '2025-11-30T12:00:00.000',
    '2026-12-07T00:00:00.000',
  ],
  DateTimeFormats.soapExtended: <String>[
    '2015-01-01T01:01:01.001+00:00',
    '2016-02-29T03:12:00.000+00:00',
    '2017-03-19T17:23:30.060+00:00',
    '2018-04-13T12:15:48.000+00:00',
    '2019-05-08T09:35:16.002+00:00',
    '2020-06-25T22:00:00.000+00:00',
    '2021-07-14T15:06:55.234+00:00',
    '2022-08-16T00:00:00.000+00:00',
    '2023-09-02T23:59:59.999+00:00',
    '2024-10-15T19:42:05.000+00:00',
    '2025-11-30T12:00:00.000+00:00',
    '2026-12-07T00:00:00.000+00:00',
  ],
  DateTimeFormats.time12Hour: <String>[
    '1:01 AM',
    '3:12 AM',
    '5:23 PM',
    '12:15 PM',
    '9:35 AM',
    '10:00 PM',
    '3:06 PM',
    '12:00 AM',
    '11:59 PM',
    '7:42 PM',
    '12:00 PM',
    '12:00 AM',
  ],
  DateTimeFormats.time12HourExtended: <String>[
    '1:01:01 AM',
    '3:12:00 AM',
    '5:23:30 PM',
    '12:15:48 PM',
    '9:35:16 AM',
    '10:00:00 PM',
    '3:06:55 PM',
    '12:00:00 AM',
    '11:59:59 PM',
    '7:42:05 PM',
    '12:00:00 PM',
    '12:00:00 AM',
  ],
  DateTimeFormats.time24Hour: <String>[
    '01:01',
    '03:12',
    '17:23',
    '12:15',
    '09:35',
    '22:00',
    '15:06',
    '00:00',
    '23:59',
    '19:42',
    '12:00',
    '00:00',
  ],
  DateTimeFormats.time24HourExtended: <String>[
    '01:01:01',
    '03:12:00',
    '17:23:30',
    '12:15:48',
    '09:35:16',
    '22:00:00',
    '15:06:55',
    '00:00:00',
    '23:59:59',
    '19:42:05',
    '12:00:00',
    '00:00:00',
  ],
  DateTimeFormats.xmlrpc: <String>[
    '20150101T01:01:01',
    '20160229T03:12:00',
    '20170319T17:23:30',
    '20180413T12:15:48',
    '20190508T09:35:16',
    '20200625T22:00:00',
    '20210714T15:06:55',
    '20220816T00:00:00',
    '20230902T23:59:59',
    '20241015T19:42:05',
    '20251130T12:00:00',
    '20261207T00:00:00',
  ],
  DateTimeFormats.xmlrpcCompact: <String>[
    '20150101T010101',
    '20160229T031200',
    '20170319T172330',
    '20180413T121548',
    '20190508T093516',
    '20200625T220000',
    '20210714T150655',
    '20220816T000000',
    '20230902T235959',
    '20241015T194205',
    '20251130T120000',
    '20261207T000000',
  ],
  r'jS M y': <String>[
    '1st Jan 15',
    '29th Feb 16',
    '19th Mar 17',
    '13th Apr 18',
    '8th May 19',
    '25th Jun 20',
    '14th Jul 21',
    '16th Aug 22',
    '2nd Sep 23',
    '15th Oct 24',
    '30th Nov 25',
    '7th Dec 26',
  ],
  r'\D\a\y z, Y': <String>[
    'Day 1, 2015',
    'Day 60, 2016',
    'Day 78, 2017',
    'Day 103, 2018',
    'Day 128, 2019',
    'Day 177, 2020',
    'Day 195, 2021',
    'Day 228, 2022',
    'Day 245, 2023',
    'Day 289, 2024',
    'Day 334, 2025',
    'Day 341, 2026',
  ],
  r'F \i\s \n\u\mb\e\r n.': <String>[
    'January is number 1.',
    'February is number 2.',
    'March is number 3.',
    'April is number 4.',
    'May is number 5.',
    'June is number 6.',
    'July is number 7.',
    'August is number 8.',
    'September is number 9.',
    'October is number 10.',
    'November is number 11.',
    'December is number 12.',
  ],
  r'h:i:s.vu a == G:i:s.vu': <String>[
    '01:01:01.001001 am == 1:01:01.001001',
    '03:12:00.000000 am == 3:12:00.000000',
    '05:23:30.060323 pm == 17:23:30.060323',
    '12:15:48.000000 pm == 12:15:48.000000',
    '09:35:16.002200 am == 9:35:16.002200',
    '10:00:00.000000 pm == 22:00:00.000000',
    '03:06:55.234000 pm == 15:06:55.234000',
    '12:00:00.000000 am == 0:00:00.000000',
    '11:59:59.999999 pm == 23:59:59.999999',
    '07:42:05.000000 pm == 19:42:05.000000',
    '12:00:00.000000 pm == 12:00:00.000000',
    '12:00:00.000000 am == 0:00:00.000000',
  ],
  r'U \s\e\co\n\d\s \s\i\n\c\e \epo\c\h.': <String>[
    '1420074061 seconds since epoch.',
    '1456715520 seconds since epoch.',
    '1489944210 seconds since epoch.',
    '1523621748 seconds since epoch.',
    '1557308116 seconds since epoch.',
    '1593122400 seconds since epoch.',
    '1626275215 seconds since epoch.',
    '1660608000 seconds since epoch.',
    '1693699200 seconds since epoch.',
    '1729021325 seconds since epoch.',
    '1764504000 seconds since epoch.',
    '1796601600 seconds since epoch.',
  ],
  r'I\S\O 8601: c': <String>[
    'ISO 8601: 2015-01-01T01:01:01+00:00',
    'ISO 8601: 2016-02-29T03:12:00+00:00',
    'ISO 8601: 2017-03-19T17:23:30+00:00',
    'ISO 8601: 2018-04-13T12:15:48+00:00',
    'ISO 8601: 2019-05-08T09:35:16+00:00',
    'ISO 8601: 2020-06-25T22:00:00+00:00',
    'ISO 8601: 2021-07-14T15:06:55+00:00',
    'ISO 8601: 2022-08-16T00:00:00+00:00',
    'ISO 8601: 2023-09-02T23:59:59+00:00',
    'ISO 8601: 2024-10-15T19:42:05+00:00',
    'ISO 8601: 2025-11-30T12:00:00+00:00',
    'ISO 8601: 2026-12-07T00:00:00+00:00',
  ],
  r'R\FC 2822: r': <String>[
    'RFC 2822: Thu, 01 Jan 2015 01:01:01 +0000',
    'RFC 2822: Mon, 29 Feb 2016 03:12:00 +0000',
    'RFC 2822: Sun, 19 Mar 2017 17:23:30 +0000',
    'RFC 2822: Fri, 13 Apr 2018 12:15:48 +0000',
    'RFC 2822: Wed, 08 May 2019 09:35:16 +0000',
    'RFC 2822: Thu, 25 Jun 2020 22:00:00 +0000',
    'RFC 2822: Wed, 14 Jul 2021 15:06:55 +0000',
    'RFC 2822: Tue, 16 Aug 2022 00:00:00 +0000',
    'RFC 2822: Sat, 02 Sep 2023 23:59:59 +0000',
    'RFC 2822: Tue, 15 Oct 2024 19:42:05 +0000',
    'RFC 2822: Sun, 30 Nov 2025 12:00:00 +0000',
    'RFC 2822: Mon, 07 Dec 2026 00:00:00 +0000',
  ],
};
